# Autodesk Sketchbook (free)
# 2016-2018 foo.li systeme + software

$packageName      = 'autodesk-sketchbook'
$packageSearch    = 'Autodesk Sketchbook*'
$version          = '8.51.0000'
$instversion      = '8.5.1.0'
$fileType         = 'msi'
$url              = 'https://cdn.sketchbook.com/win32/SketchBook_' + $instversion + '_Win32.exe'
$url64            = 'https://cdn.sketchbook.com/win64/SketchBook_' + $instversion + '_Win64.exe'
$silentArgs       = '/qn /norestart'
$validExitCodes   = @(0,3010)
#extract locally.
$unpackDir        = New-Item "${ENV:TEMP}\sketchbook" -ItemType Directory -Force
$unpackFile       = "${ENV:TEMP}\sketchbook.zip"
$setupFile        = Join-Path "$unpackDir" "SketchBook8.0.0.msi"
$setupFile64      = Join-Path "$unpackDir" "SketchBook8.0.0.msi"
$checksum         = 'F01F552FC331024525EED2759139126CE72991D9'
$checksum64       = 'A79102F559C9D8306306C6C28076AABBB6D9E25B'
$checksumType     = 'sha1'

try {
    $app = Get-ItemProperty -Path @('HKLM:\Software\Wow6432Node\Microsoft\Windows\CurrentVersion\Uninstall\*',
                                    'HKLM:\Software\Microsoft\Windows\CurrentVersion\Uninstall\*',
                                    'HKCU:\Software\Microsoft\Windows\CurrentVersion\Uninstall\*' ) `
            -ErrorAction:SilentlyContinue | Where-Object { $_.DisplayName -like $packageSearch }
     
    if ($app -and ([version]$app.DisplayVersion -ge [version]$version)) {
        Write-Output $(
        'Sketchbook ' + $version + ' (or higher) is already installed. ' +
        'No need to download and install again.'
        )
    } else {
        Get-ChocolateyWebFile $packageName $unpackFile $url $url64 `
                            -Checksum $checksum -ChecksumType $checksumType `
                            -Checksum64 $checksum64 -ChecksumType64 $checksumType
        #choco 7za fails completely...
        #Get-ChocolateyUnzip $unpackFile $unpackDir
        & "$env:ChocolateyInstall\bin\7z.exe" x -y "$env:Temp\sketchbook.zip" -o"$unpackDir"
        if ($env:PROCESSOR_ARCHITECTURE -eq 'AMD64') {
            Install-ChocolateyInstallPackage $packageName $fileType $silentArgs $setupFile64
        } else {
            Install-ChocolateyInstallPackage $packageName $fileType $silentArgs $setupFile
        }
        Write-Verbose 'cleanup...'
        Remove-Item "$env:PUBLIC\Desktop\SketchBook.lnk" -ErrorAction SilentlyContinue
        Remove-Item $unpackDir -Recurse -Force -ErrorAction SilentlyContinue
        Remove-Item $unpackFile -Recurse -Force -ErrorAction SilentlyContinue
    }
} catch {
    throw $_.Exception
}
